#!/bin/bash
# Shell script for Packege BIDO
# (C) 2010 I. Cho All Rights Reserved.

echo "<PREPRO>"

############
# prepare parameters
############
originaldatadirseismfile=$originaldatadir/seism.d

if [ -f $originaldatadirseismfile ]
then
originaldt=`cat $originaldatadirseismfile | grep '^#DT' | awk '{print $2}'`
else
originaldt=$delta_t
fi

fl0=`echo $segment_duration | awk '{print 1/$1}'`
fh0=`echo $originaldt | awk '{print 1/(2*$1)}'`
fr1=0.
fr2=0.
fr3=0.
fr4=0.
fl=$fl0
fh=$fh0
idresamp=0

# Correction for differences in instrumental response
idbp=""
yn=""
while [ "$yn" != "y" -a "$yn" != "Y" -a "$yn" != "n" -a "$yn" != "N" ]
do
    echo "Correct for differences in instrumental response? (Elimination of trends, application of tapers, bandpass filtering and decimation are included automatically) [y/n]" $yn
    read yn
    if test "$yn" == "y" -o "$yn" == "Y"; then
	idinst=1
	idtrd=1
	iddtwin=1
	idbp=1
    elif test "$yn" == "n" -o "$yn" == "N"; then
	idinst=0
    else
	echo Type y or n.
    fi
done

if [ $idinst -eq 1 ]
then
echo "The data will be corrected for differences in instrumental response according to the file \*.correction in the directory $datadir [When the file named \*.correction is not found, the waveforms will be preprocessed but no change will be took place]. "
echo "Bandpass filtering will be included automatically in the data processing."
fi

# bandpass filter
if test "$idbp" == ""
then
yn=""
while [ "$yn" != "y" -a "$yn" != "Y" -a "$yn" != "n" -a "$yn" != "N" ]
do
    echo "Bandpass filter? (Elimination of the trend, application of tapers and decimation are included automatically) [y/n]" $yn
    read yn
    if test "$yn" == "y" -o "$yn" == "Y"; then
	idtrd=1
	iddtwin=1
	idbp=1
    elif test "$yn" == "n" -o "$yn" == "N"; then
	iddtwin=0
	idbp=0
    else
	echo Type y or n.
    fi

done
fi

if test "$idbp" == "1"
then

idchkpara_prepro_ok=0
while [ $idchkpara_prepro_ok -eq 0 ] 
do
ask "Type the lower frequency limit [Hz] [this should be larger than $fl0 Hz] >" $fl
fl=$ret
ask "Type the upper frequency limit [Hz] [this should be smaller than $fh0 Hz] >" $fh
fh=$ret

idchkpara_prepro_ok=1
fl_OK=""
fh_OK=""
echo $fl | grep '[a-z,A-Z,-]' >& /dev/null
if test "$?" == "0" -o "$fl" == "" ; then
idchkpara_prepro_ok=0
fl_OK=" <-- Should be a positive real number."
fi

echo $fh | grep '[a-z,A-Z,-]' >& /dev/null
if test "$?" == "0" -o "$fh" == "" ; then
idchkpara_prepro_ok=0
fh_OK=" <-- Should be a positive real number."
fi

if [ $idchkpara_prepro_ok -eq 1 ]
then
fl_OK=`echo $fl0 $fl $fh $fh0 | awk '{fl0=$1; fl=$2; fh=$3; fh0=$4; id=1
if(fl0>=fl){printf "<-- should be higher than %f [Hz]",fl0}}'`
fh_OK=`echo $fl0 $fl $fh $fh0 | awk '{fl0=$1; fl=$2; fh=$3; fh0=$4; id=1
if(fh>=fh0){printf "<-- should be lower  than %f [Hz]",fh0}}'`
if test "$fl_OK" != "" -o  "$fh_OK" != ""
then
idchkpara_prepro_ok=0
fi
fi

if [ $idchkpara_prepro_ok -eq 1 ]
then
fl_OK=`echo $fl0 $fl $fh $fh0 | awk '{fl0=$1; fl=$2; fh=$3; fh0=$4; id=1
if(fl>=fh){printf "<-- disorder the lower and higher cutoffs"}}'`
if test "$fl_OK" != ""
then
fh_OK=$fl_OK
idchkpara_prepro_ok=0
fi
fi

if test "$idchkpara_prepro_ok" == "0";then
echo "Incorrect parameter(s) detected."
echo "The lower limit of the frequency band [$fl] >" $fl_OK
echo "The higher limit of the frequency band [$fh] >" $fh_OK
echo "Press any key to try again."
read yn
yn="n"

else

fr1=`echo $fl0 $fl $fh $fh0 | awk '{print $2-($2-$1)*0.1}'`
fr2=$fl
fr3=$fh
fr4=`echo $fl0 $fl $fh $fh0 | awk '{fcase1=$3+($4-$3)*0.1;fcase2=$3*1.2
if(fcase1<=fcase2){print fcase1}else{print fcase2}}'`
echo "The pass band is set as below."
echo "                       *--------------*"
echo "                      /F2            F3+"
echo "                     /                  +"
echo "             ------ *                    *-------> Frequency [Hz]"
echo "                    F1                   F4"
echo "F1: $fr1 [Hz] (automatically calculated)"
echo "F2: $fr2 [Hz]"
echo "F3: $fr3 [Hz]"
echo "F4: $fr4 [Hz] (automatically calculated)"
yn=""
while [ "$yn" != "y" -a "$yn" != "Y" -a "$yn" != "n" -a "$yn" != "N" ]
do
    echo "Proceed with preprocessing. OK? [y/n]"
    read yn
    if [ "$yn" == "n" -o "$yn" == "N" ];then
	idchkpara_prepro_ok=0
    fi
done
fi

done #$idchkpara_prepro_ok

else # idbp

# Eliminate trend
yn=""
while [ "$yn" != "y" -a "$yn" != "Y" -a "$yn" != "n" -a "$yn" != "N" ]
do
    echo "Eliminate the trend? (subtraction of the mean included as a special case) [y/n]" $yn
    read yn
    if test "$yn" == "y" -o "$yn" == "Y"; then
	idtrd=1
    elif test "$yn" == "n" -o "$yn" == "N"; then
	idtrd=0
    else
	echo Type y or n.
    fi

done

idbp=0

fi   # idbp

# for resamp
if [ $idbp -eq 1 ]
then
idresamp=1
else
idresamp=0
fi

############
# make message
############

# check the data length does not exceed the array dimension 
logfile=$outputdir/prepro.check_datalength.log
if [ -f $logfile ]
then
rm -f $logfile
fi
for code in $CODES
do
echo Checking the data length in $code... >>$logfile
wc -l $datadir/$code | awk 'BEGIN{print 1}{
print $1}' | $bindir/prepro               >> $logfile
echo                                      >> $logfile
done
cat $logfile | grep 'ERROR' >& /dev/null
if test "$?" == "0"
then
echo
echo ERROR detected to execute $bindir/prepro.
echo abnormal exit $0
echo See logfile: $logfile
exit 1
else
rm -f $logfile
fi

# create the directory holding the original data 
if [ ! -d $originaldatadir ]
then
mkdir -p $originaldatadir
fi

############
# main 
############

if [ ! -f $originaldatadirseismfile ]
then
mv $seismfile $originaldatadirseismfile
cp $originaldatadirseismfile $seismfile
fi

for code in $CODES
do
ifile=$originaldatadir/$code
if [ ! -f $ifile ]
then
echo NOTE: $code [in $datadir] will be moved to the directory $originaldatadir. 
mv $datadir/$code $ifile
fi
done

if [ $idinst -eq 1 ]
then
if [ -f $logfile_prepro.correction ]
then
rm -f $logfile_prepro.correction
fi
touch -f $logfile_prepro.correction
fi


for code in $CODES
do

ifile=$originaldatadir/$code
ofile=$datadir/$code
infile=$outputdir/$code.prepro.input
logfile=$outputdir/$code.prepro.log

echo "A new file will be created (overwritten) to store preprocessed data: $datadir/$code (Original data file: $originaldatadir/$code)"

tbeg=`cat $ifile | sed -n '1,1p' | awk '{print $1}'`

cat <<EOF>$infile
0
$ifile
$ofile
$idcomp0
$originaldt,$tbeg
$idtrd,$iddtwin,$tpend
$idbp,$fr1,$fr2,$fr3,$fr4
$idresamp
$idinst
EOF

if [ $idinst -eq 1 ]
then

if   [ $idcomp0 -eq 1 ]
then
instfile[1]=$ofile.u.correction
elif [ $idcomp0 -eq 2 ]
then
instfile[1]=$ofile.e.correction
instfile[2]=$ofile.n.correction
elif [ $idcomp0 -eq 3 ]
then
instfile[1]=$ofile.u.correction
instfile[2]=$ofile.e.correction
instfile[3]=$ofile.n.correction
fi

icomp=1
while [ $icomp -le $idcomp0 ]
do
if [ -f ${instfile[$icomp]} ]
then
echo "File describing differences in instrumental response, ${instfile[$icomp]}, found."
echo Correction will be made for possible differences.
echo ${instfile[$icomp]} >> $infile
basename ${instfile[$icomp]} >> $logfile_prepro.correction
else
echo "File describing differences in instrumental response, ${instfile[$icomp]}, not found."
echo No correction will be made for possible differences.
echo NOFILE >> $infile
fi
let icomp=icomp+1
done
fi # idinst

cat $infile | $bindir/prepro >& $logfile

rm -f $infile

cat $logfile | grep 'ERROR' >& /dev/null
if test "$?" == "0"
then
echo
echo ERROR detected in executing $bindir/prepro.
echo abnormal exit $0
echo See logfile: $logfile
exit 1
fi

done #code

cat $logfile | grep 'Resample_Mabiki' >& /dev/null
if test "$?" == "0"
then
resampflag=1
mabiki=`cat $logfile  | grep Resample_Mabiki        | awk '{print $2}'`
delta_t=`cat $logfile | grep ResamplingTimeInterval | awk '{print $2}'`
numdatresampled=`cat $logfile | grep NumberofDataResampled | awk '{print $2}'`
newnyquist=`cat  $logfile      | grep NewNyquistFrequency   | awk '{print $2}'`
if [ -f $seismfile ]
then
rm -f $seismfile
fi
cat $originaldatadirseismfile |  grep -v '^#DT' > $seismfile
echo "#DT $delta_t" >>$seismfile
else
resampflag=0
fi

# Write messages in the logfile
if [ -f $logfile_prepro ]
then
rm -f $logfile_prepro
fi
touch -f $logfile_prepro

if [ $idbp -eq 1 ]
then

if [ $resampflag -eq 1 -a $mabiki -gt 1 ]
then

if [ $idinst -eq 1 ]
then
cat <<EOF >> $logfile_prepro
(i.e., trend eliminated, tapers applied, bandpass filtered, decimated and corrected for differences in instrumental response).
EOF
else
cat <<EOF >> $logfile_prepro
(i.e., trend eliminated, tapers applied, bandpass filtered and decimated).
EOF
fi

else

if [ $idinst -eq 1 ]
then
cat <<EOF >> $logfile_prepro
(i.e., trend eliminated, tapers applied, bandpass filtered and corrected for differences in instrumental response).
EOF
else
cat <<EOF >> $logfile_prepro
(i.e., trend eliminated, tapers applied and bandpass filtered).
EOF
fi

fi

cat <<EOF >> $logfile_prepro
Relative length of tapers at both ends: $tpend
The pass band is:
                       *--------------*
                      /F2            F3+
                     /                  +
             ------ *                    *-------> Frequency [Hz]
                    F1                   F4
F1, F2, F3, F4: $fr1, $fr2, $fr3, $fr4 [Hz]
EOF

if [ $resampflag -eq 1 -a $mabiki -gt 1 ]
then
echo "Data points were decimated: the new time interval is $delta_t [s]." >> $logfile_prepro
echo " *Nyquist frequency of the decimated waveform    : $newnyquist [Hz]" >> $logfile_prepro
echo " *Number of data points in the decimated waveform: $numdatresampled" >> $logfile_prepro
fi

if [ $idinst -eq 1 ]
then
no_of_correction=`wc -l $logfile_prepro.correction | awk '{print $1}'`
if [ $no_of_correction -ge 1 ]
then
printf "The data were corrected for differences in instrumental response according to the file \*.correction in the directory $datadir: " >> $logfile_prepro
cat $logfile_prepro.correction | awk '{printf "%s ",$1}'  >> $logfile_prepro
echo                     | awk '{printf "\n"}'      >> $logfile_prepro
else
echo "Corrections for differences in instrumental response were attempted, but any file for correction, \*.correction, was not found in the directory $datadir. No correction was made." >> $logfile_prepro
fi
rm -f $logfile_prepro.correction

fi

else

if [ $idtrd -eq 1 ]
then
message1="trend eliminated"
else
message1="trend not eliminated"
fi

if [ $iddtwin -eq 1 ]
then
message2="tapers applied"
else
message2="tapers not applied"
fi

if [ $idtrd -eq 0 -a $iddtwin -eq 0 ]
then
cat <<EOF >> $logfile_prepro
(i.e., The waveforms were preprocessed but no change took place. They are completely the same as what they originally were).
EOF
else
cat <<EOF >> $logfile_prepro
(i.e., $message1, $message2, bandpass filter not applied).
EOF
fi

fi
